@@ -20,7 +20,7 @@ class Vuvu(QtGui.QWidget):
         
         self.color = QtGui.QColor(0, 0, 0) 
         self.setGeometry(300, 300, 800, 480)
-        self.setWindowTitle('Vuvuzela')
+        self.setWindowTitle('Vuvuzela 0.3-6')
         
         self.square = QtGui.QWidget(self)
         self.square.setGeometry(0, 0, 800, 480)       
